@@ -33,7 +33,7 @@ def test_run_test(
     with_proxy, data_pkg_repo, with_data, name, n_events, monkeypatch, record_mode
 ):
     if record_mode == "none":
-        monkeypatch.setattr(LbAPLocal.testing, "get_sso_token", lambda x, y: "")
+        monkeypatch.setattr(LbAPLocal.testing, "get_api_token", lambda x, y: "")
 
     runner = CliRunner()
     result = runner.invoke(main, ["test", "executabletests", name, "--no-validate"])
